@@ -1,10 +1,13 @@
+#
+# $Id: Perl6.pm 24376 2008-12-14 22:47:28Z azawawi $
+#
 package Syntax::Highlight::Perl6;
 
 # core modules & directives
 use 5.010;
 use strict;
 use warnings;
-use English;
+use English '-no_match_vars';  # Avoids regex performance penalty
 use Carp;
 use Encode;
 use File::Basename qw(dirname);
@@ -13,74 +16,75 @@ use Cwd qw(realpath);
 require Exporter;
 
 # cpan modules
+use Readonly;
 use Term::ANSIColor;
-use Text::VimColor;
 
 # Larry's STD.pm
 use STD;
 
 # exports and version
-our @ISA = qw(Exporter);
 our @EXPORT_OK = qw();
-our @EXPORT = qw();
-our $VERSION = '0.024';
+our $VERSION = '0.025';
 
 # filename constants
-use constant FILE_CSS    => "p6_style.css";
-use constant FILE_ANSI   => "p6_style.ansi";
-use constant FILE_JS     => "p6_style.js";
-use constant FILE_JQUERY => "jquery-1.2.6.pack.js";
-use constant FILE_P6_VIM => "perl6.vim";
- 
+Readonly my $FILE_CSS    => 'p6_style.css';
+Readonly my $FILE_ANSI   => 'p6_style.ansi';
+Readonly my $FILE_JS     => 'p6_style.js';
+Readonly my $FILE_JQUERY => 'jquery-1.2.6.pack.js';
+Readonly my $FILE_P6_VIM => 'perl6.vim';
+
 # These are needed for redspans
-$::ACTIONS = 'Actions';
+$::ACTIONS = __PACKAGE__ . '::Actions';
 
 # my module variables
 my ($src_text,$parser,@loc);
 my $parsed_lazily = 0;
 
 #find out the real path of the rsc directory
-croak "Syntax::Highlight::Perl6 cannot see where it is installed"
-    unless -f __FILE__;
+if(! -f __FILE__) {
+    croak 'Syntax::Highlight::Perl6 cannot see where it is installed'
+}
 my $SHARED = realpath(File::Spec->join(
-            dirname(__FILE__),"../../rsc"));
+            dirname(__FILE__),'../../rsc'));
 
 #----------------------------------------------------------------
-# Returns the syntax highlighting object. It needs a hash 
+# Returns the syntax highlighting object. It needs a hash
 # of options.
 #----------------------------------------------------------------
-sub new($%) {
+sub new {
     my ($class, %options) = @ARG;
     $options{rule} = $options{rule} // 'comp_unit';
     $options{inline_resources} = $options{inline_resources} // 0;
-    $options{resource_url} = $options{resource_url} // qq{};
-    $options{page_title} = $options{page_title} // qq{};
+    $options{resource_url} = $options{resource_url} // q{};
+    $options{page_title} = $options{page_title} // q{};
     $options{utf8_decode} = $options{utf8_decode} // 1;
 
     #is 'text' undefined?
-    croak "'text' option is not found in $class->new" 
+    croak "'text' option is not found in $class->new"
         if (!$options{text});
-    
-    return bless(\%options, $class);
+
+    return bless \%options, $class;
 }
 
 #----------------------------------------------------------------
 # Lazily parses the source string using STD.pm (only once)
 # (private)
 #----------------------------------------------------------------
-sub _lazy_parse($) {
+sub _lazy_parse {
     my $self = shift;
-    
+
     if(!$parsed_lazily) {
-    
+
         # utf8-decode if required
-        $src_text = $self->{utf8_decode} ? 
-            decode('utf8', $self->{text} ) : 
+        $src_text = $self->{utf8_decode} ?
+            decode('utf8', $self->{text} ) :
             $self->{text};
-        
-        #grow the loc array while checking for empty strings 
-        my $len = length($src_text);
-        $src_text = " " if $len == 0;
+
+        #grow the loc array while checking for empty strings
+        my $len = length $src_text;
+        if($len == 0) {
+            $src_text = q{ };
+        }
         $loc[$len - 1] = [];
 
         #STD parse the text for the rule provided
@@ -89,6 +93,7 @@ sub _lazy_parse($) {
         #we parsed it lazily...
         $parsed_lazily = 1;
     }
+    return;
 }
 
 
@@ -96,15 +101,15 @@ sub _lazy_parse($) {
 # Returns snippet htmls which can embedded without any side effects
 # on your page
 #---------------------------------------------------------------------
-sub snippet_html($) {
+sub snippet_html {
     my $self = shift;
-    my $str = "";
+    my $str = q{};
 
     $self->_lazy_parse();
-    
+
     my %colors = _read_css_file();
-    
-    $str .= "<pre>";
+
+    $str .= '<pre>';
 
     local *spit_snippet_html = sub {
         my ($i, $buffer, $rule, $tree) = @ARG;
@@ -116,35 +121,33 @@ sub snippet_html($) {
             $str .= $buffer;
         }
     };
-    _redspans_traverse(\&spit_snippet_html,%colors); 
+    _redspans_traverse(\&spit_snippet_html,%colors);
 
-    $str .= "</pre>";
+    $str .= '</pre>';
 
-    $str;
+    return $str;
 }
 #---------------------------------------------------------------
-# Returns the Perl 6 highlighted HTML string 
+# Returns the Perl 6 highlighted HTML string
 # (without the JavaScript stuff).
 #---------------------------------------------------------------
-sub simple_html($) {
+sub simple_html {
     my $self = shift;
-    my $str = "";
+    my $str = q{};
 
     $self->_lazy_parse();
 
     my %colors = _read_css_file();
- 
+
     # slurp css inline it
-    my $css; 
+    my $css;
     if($self->{inline_resources}) {
-        $css = _slurp(_shared(FILE_CSS))
+        $css = _slurp(_shared($FILE_CSS))
             or croak "Error while slurping file: $OS_ERROR\n";
         $css = qq{<style type="text/css">\n$css\n</style>};
     } else {
         my $prefix = $self->{resource_url};
-        $css = qq{<link href="$prefix} . 
-            FILE_CSS . 
-            qq{" rel="stylesheet" type="text/css">};
+        $css = qq{<link href="$prefix$FILE_CSS" rel="stylesheet" type="text/css">};
     }
     my $page_title = $self->{page_title};
     my $timestamp = localtime;
@@ -171,24 +174,24 @@ HTML
         }
     };
 
-    _redspans_traverse(\&spit_simple_html,%colors); 
+    _redspans_traverse(\&spit_simple_html,%colors);
 
-    $str .= <<"HTML";
+    $str .= <<'HTML';
     </pre>
 </body>
 </html>
 HTML
 
-   $str;
+   return $str;
 }
 
 #-------------------------------------------------------------------
 # Returns the Perl 6 highlighted HTML string. The HTML consists of a
 # JavaScript Parse Tree Viewer along with CSS-styling.
 #-------------------------------------------------------------------
-sub full_html($) {
+sub full_html {
     my $self = shift;
-    my $str = "";
+    my $str = q{};
 
     $self->_lazy_parse();
 
@@ -197,27 +200,21 @@ sub full_html($) {
     my ($jquery_js,$js,$css);
     if($self->{inline_resources}) {
         my $contents;
-        $contents = _slurp(_shared(FILE_JQUERY)) 
-            or croak "Error while slurping file: $OS_ERROR\n";    
+        $contents = _slurp(_shared($FILE_JQUERY))
+            or croak "Error while slurping file: $OS_ERROR\n";
         $jquery_js = qq{<script type="text/javascript">\n$contents\n</script>};
-        $contents = _slurp(_shared(FILE_JS)) 
+        $contents = _slurp(_shared($FILE_JS))
             or croak "Error while slurping file: $OS_ERROR\n";
         $js = qq{<script type="text/javascript">\n$contents\n</script>};
-        $contents = _slurp(_shared(FILE_CSS))
+        $contents = _slurp(_shared($FILE_CSS))
             or croak "Error while slurping file: $OS_ERROR\n";
         $css = qq{<style type="text/css">\n$contents\n</style>};
     } else {
-        my $prefix = $self->{resource_url};  
-        $jquery_js = 
-            qq{<script type="text/javascript" src="$prefix} . 
-            FILE_JQUERY . 
-            qq{"></script>};
-        $js = qq{<script type="text/javascript" src="$prefix} .
-            FILE_JS . 
-            qq{"></script>};
-        $css = qq{<link href="$prefix} .
-            FILE_CSS . 
-            qq{" rel="stylesheet" type="text/css">};
+        my $prefix = $self->{resource_url};
+        $jquery_js =
+            qq{<script type="text/javascript" src="$prefix$FILE_JQUERY"></script>};
+        $js = qq{<script type="text/javascript" src="$prefix$FILE_JS"></script>};
+        $css = qq{<link href="$prefix$FILE_CSS" rel="stylesheet" type="text/css">};
     }
 
     my $page_title = $self->{page_title};
@@ -254,23 +251,23 @@ HTML
         }
     };
 
-    _redspans_traverse(\&spit_full_html,%colors); 
+    _redspans_traverse(\&spit_full_html,%colors);
 
-    $str .= <<"HTML";
+    $str .= <<'HTML';
     </pre>
 </body>
 </html>
 HTML
 
-    $str;
+    return $str;
 }
 
 #---------------------------------------------------------------
 # Returns a Perl highlighted ANSI escape color string.
 #---------------------------------------------------------------
-sub ansi_text($) {
+sub ansi_text {
     my $self = shift;
-    my $str = "";
+    my $str = q{};
 
     $self->_lazy_parse();
 
@@ -286,9 +283,9 @@ sub ansi_text($) {
         }
     };
 
-    _redspans_traverse(\&spit_ansi_text,%colors); 
+    _redspans_traverse(\&spit_ansi_text,%colors);
 
-    $str;
+    return $str;
 }
 
 #---------------------------------------------------------------
@@ -296,56 +293,69 @@ sub ansi_text($) {
 # The array consists of one or more of the following record:
 #   ($position, $buffer, $rule_name, $parse_tree)
 #---------------------------------------------------------------
-sub parse_trees($) {
+sub parse_trees {
     my $self = shift;
 
     $self->_lazy_parse();
 
     my %colors = _read_ansi_file();
-    my $parse_trees = []; 
+    my $parse_trees = [];
     local *spit_parse_tree = sub {
-        push @$parse_trees, [@ARG];
+        push @{$parse_trees}, [@ARG];
     };
 
-    _redspans_traverse(\&spit_parse_tree,%colors); 
+    _redspans_traverse(\&spit_parse_tree,%colors);
 
-    $parse_trees;
+    return $parse_trees;
 }
 
 #---------------------------------------------------------------
-# Returns a Perl 6 VIM syntax highlighted string using 
-# Text::VimColor and perl6.vim 
+# Returns a Perl 6 VIM syntax highlighted string using
+# Text::VimColor and perl6.vim
+# Note: works only if Text::VimColor is installed
 #---------------------------------------------------------------
 sub vim_html {
     my $self = shift;
 
+    #This is an optional package so we're going to test for it
+    eval { require Text::VimColor; 1; }
+        or croak "Text::VimColor is not currently installed.\n" .
+            "You may also need to copy perl6.vim manually to ~/.vim/syntax\n" .
+            "perl6.vim is found at:\n" .
+            _shared($FILE_P6_VIM) . "\n";
+
     my $syntax = Text::VimColor->new(
         string => $self->{text},
         filetype => 'perl6',
         html_full_page => 1
     );
 
-    $syntax->html;
+    return $syntax->html;
 }
 
 #--------------------------------------------------------------------
-# Reads the css file and return a hash of colors 
-#-------------------------------------------------------------------- 
-sub _read_css_file() {
+# Reads the css file and return a hash of colors
+#--------------------------------------------------------------------
+sub _read_css_file {
 
     my %colors = ();
-    my $filename = _shared(FILE_CSS);
-    open FILE, $filename
+    my $filename = _shared($FILE_CSS);
+    my $fh = IO::File->new($filename)
         or croak "Could not open $filename: $OS_ERROR\n";
     my $line;
-    while($line = <FILE>) {
-        if($line =~ /^\s*\.(\w+)\s*{\s*(.+?)\s*}/) {
+    while($line = <$fh>) {
+        if($line =~ /^\s*           # <whitespace>
+                    \.(\w+)\s*      # .<css class>
+                    {\s*(.+?)\s*}   # { <css style>* }
+                    /x)
+        {
             $colors{$1} = $2;
         }
     }
-    close FILE;
+    close $fh
+        or croak "Could not close $filename";
 
-    %colors;
+    return %colors;
 }
 
 #--------------------------------------------------------------
@@ -354,76 +364,86 @@ sub _read_css_file() {
 #--------------------------------------------------------------
 sub _read_ansi_file {
     my %colors = ();
-    my $filename = _shared(FILE_ANSI);
-    open FILE, $filename
+    my $filename = _shared($FILE_ANSI);
+    my $fh = IO::File->new($filename)
         or croak "Could not open $filename: $OS_ERROR\n";
     my $line;
-    while($line = <FILE>) {
-        if($line =~ /^(\w+)=(.+)$/) {
+    while($line = <$fh>) {
+        if($line =~ m{^(\w+)     # <start> <rule-name>
+                    =(.+)$      # <=> <ansi-color> <end>
+                    }x)
+        {
             $colors{$1} = $2;
         }
     }
-    close FILE;
+    close $fh
+        or croak "Could not close $filename";
 
-    %colors;
+    return %colors;
 }
 
 
 #---------------------------------------------------------------
-#    Helper private method that traverses STD.pm's parse 
-# tree array. It needs a callback process_buffer and a 
+#    Helper private method that traverses STD.pm's parse
+# tree array. It needs a callback process_buffer and a
 # colors hash.
 #---------------------------------------------------------------
-sub _redspans_traverse($%) {
+sub _redspans_traverse {
     my ($process_buffer,%colors) = @ARG;
 
-    my ($last_tree,$buffer, $last_type) = ("","","");
+    my ($last_tree,$buffer, $last_type) = (q{},q{},q{});
     for my $i (0 .. @loc-1) {
-        next unless defined $loc[$i];
-        my $c = substr($src_text,$i,1);
-        my $tree = "";
+        if(! defined $loc[$i]) {
+            next;
+        }
+        my $c = substr $src_text, $i, 1;
+        my $tree = q{};
         for my $action_ref (@{$loc[$i]}) {
-            $tree .= ${$action_ref} . " ";
+            $tree .= ${$action_ref} . q{ };
         }
         if($tree ne $last_tree) {
-            my $rule;
             my $rule_to_color = 0;
             $buffer = $buffer;
             my @rules = ();
-            @rules = reverse(split / /,$last_tree) if $last_tree ne '';
-            for $rule (@rules) {
+            if($last_tree ne q{}) {
+                @rules = reverse split / /,$last_tree;
+            }
+            for my $rule (@rules) {
                 if($rule eq 'unv') {
                     $rule_to_color = '_comment';
                     last;
-                } elsif($colors{$rule} && $buffer ne '') {
+                } elsif($colors{$rule} && $buffer ne q{}) {
                     $rule_to_color = $rule;
                     last;
                 }
             }
             if($rule_to_color) {
-                if($last_tree =~ /\sidentifier/) {
-                    if($last_type ne '') {
+                if($last_tree =~ /\sidentifier/x) {
+                    if($last_type ne q{}) {
                         $rule_to_color = $last_type;
-                        $last_type = '';
-                    } 
-                } elsif($last_tree =~ /\ssigil/) {
+                        $last_type = q{};
+                    }
+                } elsif($last_tree =~ /\ssigil/x) {
                     given($buffer) {
                         when ('$') { $last_type = '_scalar'; }
                         when ('@') { $last_type = '_array'; }
                         when ('%') { $last_type = '_hash'; }
-                        default { $last_type = ''; }
-                    }      
-                    $rule_to_color = $last_type if $last_type ne ''; 
-                }             
+                        default { $last_type = q{}; }
+                    };
+                    if($last_type ne q{}) {
+                        $rule_to_color = $last_type;
+                    }
+                }
             }
             #now delegate printing to a callback
-            $process_buffer->($i, $buffer, $rule_to_color, $last_tree); 
+            $process_buffer->($i, $buffer, $rule_to_color, $last_tree);
             $buffer = $c;
         } else {
             $buffer .= $c;
         }
         $last_tree = $tree;
     }
+    return;
 }
 
 #------------------------------------------------------------------
@@ -431,8 +451,8 @@ sub _redspans_traverse($%) {
 # STD.pm calls this method when you call STD->parse(...)
 # and we populate @loc with action references and parse trees...
 #------------------------------------------------------------------
-{ 
-    package Actions;
+{
+    package Syntax::Highlight::Perl6::Actions;
 
     our $AUTOLOAD;
 
@@ -443,8 +463,11 @@ sub _redspans_traverse($%) {
         my $C = shift;
         my $F = $C->{_from};
         my $P = $C->{_pos};
-        $AUTOLOAD =~ s/^Actions:://;
-        $loc[$P] = [] if $loc[$P];	# in case we backtracked to here
+        $AUTOLOAD =~ s/^Syntax::Highlight::Perl6::Actions:://x;
+        if($loc[$P]) {
+            # in case we backtracked to here
+            $loc[$P] = []
+        }
         my $action = $AUTOLOAD;
         my $action_ref = $action_refs{$action};
         if(!$action_ref) {
@@ -453,6 +476,7 @@ sub _redspans_traverse($%) {
         for ($F..$P-1) {
             unshift @{$loc[$_]}, $action_ref;
         }
+        return;
     }
 
     sub stdstopper { }
@@ -462,36 +486,45 @@ sub _redspans_traverse($%) {
 }
 
 #---------------------------------------------------------------
-# Private method to converts characters to their equivalent 
+# Private method to converts characters to their equivalent
 # html entities.
 #----------------------------------------------------------------
-sub _escape_html($) {
+sub _escape_html {
     my $str = shift;
     my %esc = (
         '<'     => '&lt;',
         '>'     => '&gt;',
         '"'     => '&quot;',
-        '&'     => '&amp;'
+        '&'     => '&amp;',
     );
-    my $re = join '|', map quotemeta, keys %esc;
-    $str =~ s/($re)/$esc{$1}/g;
+    my $re = join '|',
+        map { quotemeta } keys %esc;
+    $str =~ s/($re)      # convert <>"&
+             /$esc{$1}   # to their html escape sequences
+             /gx;
     return $str;
 }
 
 #-----------------------------------------------------
 # convert to shared package real resource path
 #-----------------------------------------------------
-sub _shared($) {
+sub _shared {
     return File::Spec->join($SHARED, shift);
 }
 
 #-----------------------------------------------------
 # Load file into a scalar without File::Slurp
-# Thanks ofcourse to this post
-# http://www.perlmonks.org/?node_id=20235
+# see perlfaq5
 #-----------------------------------------------------
-sub _slurp($) {
-    local $/ =<> if local @ARGV = @_
+sub _slurp {
+    my $filename = shift;
+    my $fh = IO::File->new($filename)
+        or croak "Could not open $filename for reading";
+    local $INPUT_RECORD_SEPARATOR = undef;   #enable localized slurp mode
+    my $contents = <$fh>;
+    close $fh
+        or croak "Could not close $filename";
+    return $contents;
 }
 
 1;
@@ -526,7 +559,7 @@ Syntax::Highlight::Perl6 - a Perl 6 syntax highlighter
     # Prints ANSI escaped color sequences (useful for console and IRC output)
     print $p->ansi_text;
 
-    # Prints the Perl 5 array of parse trees (useful for building stuff on top of it) 
+    # Prints the Perl 5 array of parse trees (useful for building stuff on top of it)
     print $p->parse_trees;
 
     # Prints VIM syntax highlighted html
@@ -536,8 +569,8 @@ Syntax::Highlight::Perl6 - a Perl 6 syntax highlighter
 
 This module parses Perl 6 source code using STD.pm, then matches nodes to colors
 and returns them in different output formats.
-It can be used to create web pages with colorful source code samples in its 
-simple and snippet html modes, or it can be used as a learning tool in examining 
+It can be used to create web pages with colorful source code samples in its
+simple and snippet html modes, or it can be used as a learning tool in examining
 STD.pm's parsing using the JavaScript node viewer in its full html mode.
 
 The available output formats are:
@@ -555,67 +588,67 @@ The available output formats are:
 
 =back
 
-=head1 METHODS
+=head1 SUBROUTINES/METHODS
 
 The following methods are available:
 
 =over 4
 
-=item new(options)
+=item * new(options)
 
 Returns the syntax highlighting object. It needs a hash of options.
 The following options are available:
 
 =over 4
 
-=item text
+=item * text
 
-I<This is a required option.> 
+I<This is a required option.>
 This is where you should provide the Perl 6 code.
 
-=item rule
+=item * rule
 
 parse rule name for STD.pm to parse against (default: comp_unit)
 
-=item inline_resources
+=item * inline_resources
 
 Flag to enable/disable CSS/JavaScript HTML inlining. (default: 0 (Disabled))
 
-=item resource_url
+=item * resource_url
 
 HTML resource url that will be appended when resource inlining is disabled.
 
-=item page_title
+=item * page_title
 
-HTML page title for C<simple_html> and C<full_html> (default: '')
+HTML page title for C<simple_html> and C<full_html> (default: q{})
 
-=item utf8_decode
+=item * utf8_decode
 
 Flag to enable/disable utf8 decoding. (default: 1 (Enabled))
 
 =back
 
-=item snippet_html()
+=item * snippet_html()
 
-Returns the Perl 6 highlighted HTML string that can be embedded. 
+Returns the Perl 6 highlighted HTML string that can be embedded.
 No CSS or JavaScript is inside.
 
-=item simple_html()
+=item * simple_html()
 
-Returns the Perl 6 highlighted HTML string. The HTML code is the same 
-as C<full_html> but lacks a JavaScript Parse Tree Viewer. 
+Returns the Perl 6 highlighted HTML string. The HTML code is the same
+as C<full_html> but lacks a JavaScript Parse Tree Viewer.
 
-=item full_html()
+=item * full_html()
 
-Returns the Perl 6 highlighted HTML string. The HTML consists of a 
-JavaScript Parse Tree Viewer along with CSS-styling. 
-It can inlined if C<inline_resources> option is 1. 
+Returns the Perl 6 highlighted HTML string. The HTML consists of a
+JavaScript Parse Tree Viewer along with CSS-styling.
+It can inlined if C<inline_resources> option is 1.
 
-=item ansi_text()
+=item * ansi_text()
 
 Returns a Perl highlighted ANSI escape color string.
 
-=item parse_trees()
+=item * parse_trees()
 
 Returns a Perl 5 array containing parse tree records.
 The array consists of one or more of the following record:
@@ -638,73 +671,73 @@ The array consists of one or more of the following record:
     #        'statementlist eat_terminator '
     #      ]
 
-=item vim_html()
+=item * vim_html()
 
-Returns the Perl 6 VIM-highlighted HTML string. This uses C<Text::VimColor>
-to utilize VIM's excellent syntax coloring engine. Please remember to copy
-perl6.vim to your .vim/syntax. And remember that this is purely for fun. 
-If you dont have vim, then it wont work.
+Returns the Perl 6 highlighted HTML string that was generated using
+VIM's excellent syntax coloring engine. Please remember to copy
+perl6.vim to your ~/.vim/syntax.
+
+NOTE: This method needs VIM to work properly along with L<Text::VimColor>.
 
 =back
 
 =head1 SEE ALSO
 
-Discussion about this module and STD.pm is usually in #perl6 @ irc.freenode.net
+L<Text::VimColor>
 
-Larry Wall's STD.pm lives in http://svn.pugscode.org/pugs/src/perl6/
+Discussion about this module and STD.pm is usually in #perl6
+(irc://irc.freenode.net/perl6). Larry Wall's C<STD.pm> lives in
+http://svn.pugscode.org/pugs/src/perl6 . C<perl6.vim> lives in
+http://svn.pugscode.org/pugs/util/perl6.vim .
 
-=head1 BUGS
+=head1 BUGS AND LIMITATIONS
 
-What's a programmer's life without a few bugs to solve:
+If you find any bugs, please submit them to
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=Syntax::Highlight::Perl6. Thanks.
+
+These are the bugs that i am currently aware of:
 
 =over 4
 
-=item Can't call method "bless" on an undefined value at STD.pm line 5269.
+=item * Can't call method "bless" on an undefined value at STD.pm line 5269.
 
 You have to put "use STD;" before using this module.
 
     use STD; # this must be first for now
     use Syntax::Highlight::Perl6;
 
-=item A log file is always created when using this module.
+=item * A log file is always created when using this module.
 
 This is a bug and im working on it. Most probably it is STD.pm-related
 
-=item Directory 'lex' is created when using this module.
+=item * Directory 'lex' is created when using this module.
 
 STD.pm caches digraphs and the matched rules in there.
 So this is Pretty Voodoo Stuff. Otherwise it will be pretty slow.
 
-=item Slow startup when using the module for the first time
+=item * Slow startup when using the module for the first time
 
-That is related to the creation of the cached 'lex'ing directory by STD.pm. 
+That is related to the creation of the cached 'lex'ing directory by STD.pm.
 I<This happens only once.>
 
 =back
 
 =head1 AUTHOR
 
-Ahmad Zawawi, E<lt>ahmad.zawawi@gmail.comE<gt>
-
-Written by Ahmad M. Zawawi (azawawi), Moritz Lenz and Paweł Murias (pmurias)
-
-The project idea was inspired by Moritz Lenz (moritz)
-See http://www.nntp.perl.org/group/perl.perl6.users/2008/07/msg788.html
+Written by Ahmad M. Zawawi E<lt>ahmad.zawawi@gmail.comE<gt> (aka azawawi in #perl6).
 
+The project idea was inspired by Moritz Lenz (moritz) -
+http://www.nntp.perl.org/group/perl.perl6.users/2008/07/msg788.html .
+Larry Wall's C<gimme5>-generated Perl5 C<STD.pmc> is included to parse Perl 6 code.
 The initial STD tree traversal code was written by Paweł Murias (pmurias).
+It was replaced afterwards for performance reasons with Larry Wall's
+C<redspans> traversal code. C<redspans> stands for C<red> for reductions,
+and C<spans> from the "from/to span calculations". The included perl6.vim
+is written by Luke Palmer, Moritz Lenz, and Hinrik Ãn Sigurðsson. T
 
-A C<gimme5>-generated Perl5 C<STD.pmc> is included to parse Perl 6 code.
+Thanks guys. I could not have done it without you ;-)
 
-The C<redspans> traversal code was written by Larry Wall (TimToady).
-
-C<redspans> stands for C<red> for reductions, and C<spans> from the 
-from/to span calculations".
-
-The JavaSript jQuery code was written by Ahmad M. Zawawi (azawawi)
-
-Thanks for perl6.vim Luke Palmer, Moritz Lenz, and Hinrik Ãn Sigurðsson
-
-=head1 COPYRIGHT AND LICENSE
+=head1 LICENSE AND COPYRIGHT
 
 Copyright (C) 2008 by Ahmad Zawawi
 
